diff src/share/vm/oops/instanceOop.hpp @ 12355:cefad50507d8

Merge with hs25-b53
author Gilles Duboscq <duboscq@ssw.jku.at>
date Fri, 11 Oct 2013 10:38:03 +0200
parents 7944aba7ba41
children de6a9e811145
line wrap: on
line diff
--- a/src/share/vm/oops/instanceOop.hpp	Thu Oct 10 18:26:22 2013 +0200
+++ b/src/share/vm/oops/instanceOop.hpp	Fri Oct 11 10:38:03 2013 +0200
@@ -37,9 +37,9 @@
 
   // If compressed, the offset of the fields of the instance may not be aligned.
   static int base_offset_in_bytes() {
     // offset computation code breaks if UseCompressedKlassPointers
     // only is true
-    return (UseCompressedOops && UseCompressedKlassPointers) ?
+    return (UseCompressedOops && UseCompressedClassPointers) ?
              klass_gap_offset_in_bytes() :
              sizeof(instanceOopDesc);
   }
@@ -37,9 +37,9 @@
   // If compressed, the offset of the fields of the instance may not be aligned.
   static int base_offset_in_bytes() {
-    // offset computation code breaks if UseCompressedKlassPointers
+    // offset computation code breaks if UseCompressedClassPointers
     // only is true